@@ -4,13 +4,21 @@ Utilities for manipulating formatted text.
 When ``to_formatted_text`` has been called, we get a list of ``(style, text)``
 tuples. This file contains functions for manipulating such a list.
 """
+from __future__ import annotations
+
 from typing import Iterable, cast
 
 from prompt_toolkit.utils import get_cwidth
 
-from .base import OneStyleAndTextTuple, StyleAndTextTuples
+from .base import (
+    AnyFormattedText,
+    OneStyleAndTextTuple,
+    StyleAndTextTuples,
+    to_formatted_text,
+)
 
 __all__ = [
+    "to_plain_text",
     "fragment_list_len",
     "fragment_list_width",
     "fragment_list_to_text",
@@ -18,6 +26,13 @@ __all__ = [
 ]
 
 
+def to_plain_text(value: AnyFormattedText) -> str:
+    """
+    Turn any kind of formatted text back into plain text.
+    """
+    return fragment_list_to_text(to_formatted_text(value))
+
+
 def fragment_list_len(fragments: StyleAndTextTuples) -> int:
     """
     Return the amount of characters in this text fragment list.
@@ -57,13 +72,15 @@ def fragment_list_to_text(fragments: StyleAndTextTuples) -> str:
     return "".join(item[1] for item in fragments if ZeroWidthEscape not in item[0])
 
 
-def split_lines(fragments: StyleAndTextTuples) -> Iterable[StyleAndTextTuples]:
+def split_lines(
+    fragments: Iterable[OneStyleAndTextTuple],
+) -> Iterable[StyleAndTextTuples]:
     """
     Take a single list of (style_str, text) tuples and yield one such list for each
     line. Just like str.split, this will yield at least one item.
 
-    :param fragments: List of (style_str, text) or (style_str, text, mouse_handler)
-                      tuples.
+    :param fragments: Iterable of ``(style_str, text)`` or
+        ``(style_str, text, mouse_handler)`` tuples.
     """
     line: StyleAndTextTuples = []
 
