@@ -1,5 +1,5 @@
 # pylint: disable=function-redefined
-from typing import Dict, Union
+from __future__ import annotations
 
 from prompt_toolkit.application.current import get_app
 from prompt_toolkit.buffer import Buffer, indent, unindent
@@ -425,7 +425,7 @@ def load_emacs_shift_selection_bindings() -> KeyBindingsBase:
             return
 
         # the other keys are handled through their readline command
-        key_to_command: Dict[Union[Keys, str], str] = {
+        key_to_command: dict[Keys | str, str] = {
             Keys.ShiftLeft: "backward-char",
             Keys.ShiftRight: "forward-char",
             Keys.ShiftHome: "beginning-of-line",
