@@ -1,4 +1,4 @@
-from typing import List, Optional
+from __future__ import annotations
 
 from .key_processor import KeyPress
 
@@ -15,22 +15,22 @@ class EmacsState:
     def __init__(self) -> None:
         # Simple macro recording. (Like Readline does.)
         # (For Emacs mode.)
-        self.macro: Optional[List[KeyPress]] = []
-        self.current_recording: Optional[List[KeyPress]] = None
+        self.macro: list[KeyPress] | None = []
+        self.current_recording: list[KeyPress] | None = None
 
     def reset(self) -> None:
         self.current_recording = None
 
     @property
     def is_recording(self) -> bool:
-        " Tell whether we are recording a macro. "
+        "Tell whether we are recording a macro."
         return self.current_recording is not None
 
     def start_macro(self) -> None:
-        " Start recording macro. "
+        "Start recording macro."
         self.current_recording = []
 
     def end_macro(self) -> None:
-        " End recording macro. "
+        "End recording macro."
         self.macro = self.current_recording
         self.current_recording = None
